@@ -1498,6 +1498,7 @@ impl Merge for TransformConfig {
         self.optimizer.merge(&from.optimizer);
         self.const_modules.merge(&from.const_modules);
         self.react.merge(&from.react);
+        self.hidden.merge(&from.hidden);
     }
 }
 
@@ -1527,6 +1528,12 @@ impl Merge for ConstModulesConfig {
     }
 }
 
+impl Merge for HiddenTransformConfig {
+    fn merge(&mut self, from: &Self) {
+        self.jest |= from.jest;
+    }
+}
+
 fn build_resolver(base_url: PathBuf, paths: CompiledPaths) -> SwcImportResolver {
     static CACHE: Lazy<DashMap<(PathBuf, CompiledPaths), SwcImportResolver, ahash::RandomState>> =
         Lazy::new(|| Default::default());
